# Mechanical details

## Raspberry Pi 4

- Board dimension: 85 x 56 mm
- Board thickness: 1 mm
- Pins header height: 8.5 mm
- Highest component(*): 6.0 mm

(*) appart from the pin headers

## Daughter board PCB 

- Dimension: 56 x 65 mm
- Thickness: 1.6 mm

## 2x20 PCB Socket

Ref: Multicomp Pro 2214S-40SG-85PCB

- Mating length: 6.11 mm
- Connector height: 8.4 mm
- Pins (tail) length: 3.1 mm
- Total height: 11.5 mm

## 2x5 Pin Header

Ref: Multicomp Pro 2213S-10G

- Mating length: 6.0 mm
- pastic thickness: 2.54 mm
- Connector height: 8.54 mm
- Pins (tail) length: 3.0 mm
- Total length: 11.54 mm (including base)

## 2x5 IDC socket

Ref: Amphenol T812110A101CEU

Height with strain relief: 13.55 mm
Height wthout strain relief: 10.58 mm

# Drawing

- [RetroDevEm pencil mechanical drawing](../pictures/retrodevem-pencil-mechanical-drawing.pdf)
- [RetroDevEm pen mechanical drawing](../pictures/retrodevem-pen-mechanical-drawing.pdf)
